@@ -76,6 +76,72 @@ def build_output(result):
     global instances_outputs
     instances_outputs[result[0]] = result[1]
 
+def exec_command(rg, cg, cont, command, max_retries):
+    env = os.environ.copy()
+    env["PATH"] = "/usr/sbin:/sbin:" + env["PATH"]
+    # Kill tmux window
+    subprocess.Popen(["tmux", "kill-session", "-t", cont], env=env)
+    time.sleep(2)
+    subprocess.Popen(["tmux", "new-session", "-d", "-s", cont], env=env)
+    time.sleep(5)
+    subprocess.Popen(["tmux", "send-keys", "-t", cont,
+                    f"az container exec -g {rg} -n {cg} --container-name {cont} --exec-command /bin/bash", "Enter",
+                    ], env=env)
+    time.sleep(15)
+    subprocess.Popen(["tmux", "send-keys", "-t", cont, f"nohup python3 -m acido.cli -sh '{command}' > temp &", "Enter"], env=env)
+    time.sleep(2)
+    subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
+
+    output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env).decode()
+
+    time.sleep(4)
+
+    retries = 0
+    failed = False
+
+    while 'Done' not in output or 'Exit' not in output:
+
+        retries += 1
+
+        if retries > max_retries:
+            output = ''
+            failed = True
+            break
+
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
+        time.sleep(5)
+        output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env).decode()
+
+        if 'Done' in output:
+            break
+
+    if not failed:
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
+        time.sleep(2)
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, "(cat temp) > output", "Enter", "Enter"], env=env)
+        time.sleep(5)
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, "cat output", "Enter"], env=env)
+        time.sleep(10)
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
+        time.sleep(2)
+
+        try:
+            output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env)
+            output = output.decode()
+            print(output)
+        except Exception as e:
+            output = None
+            print(bad(f'Error capturing output from: {bold(cont)}'))
+
+
+    # Kill shell
+    subprocess.Popen(["tmux", "send-keys", "-t", cont, "(rm temp && rm output && exit)", "Enter"], env=env)
+    time.sleep(1)
+    # Kill tmux window
+    subprocess.Popen(["tmux", "kill-session", "-t", cont], env=env)
+
+    return cont, output
+
 class Acido(object):
 
     if args.interactive:
@@ -259,71 +325,8 @@ class Acido(object):
                 print(good(f'Input written to: {filename}'))
         return input_file
 
-    def exec_command(self, cg, cont, command, max_retries):
-        env = os.environ.copy()
-        env["PATH"] = "/usr/sbin:/sbin:" + env["PATH"]
-        subprocess.Popen(["tmux", "new-session", "-d", "-s", cont], env=env)
-        time.sleep(1)
-        subprocess.Popen(["tmux", "send-keys", "-t", cont,
-                        f"az container exec -g {self.rg} -n {cg} --container-name {cont} --exec-command /bin/bash", "Enter",
-                        ], env=env)
-        time.sleep(15)
-        subprocess.Popen(["tmux", "send-keys", "-t", cont, f"nohup python3 -m acido.cli -sh '{command}' > temp &", "Enter"], env=env)
-        time.sleep(2)
-        subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
-
-        output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env).decode()
-
-        time.sleep(4)
-
-        retries = 0
-        failed = False
-
-        while 'Done' not in output:
-
-            retries += 1
-
-            if retries > max_retries:
-                output = ''
-                failed = True
-                break
-
-            subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
-            time.sleep(5)
-            output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env).decode()
-
-            if 'Done' in output:
-                break
-
-        if not failed:
-            subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
-            time.sleep(2)
-            subprocess.Popen(["tmux", "send-keys", "-t", cont, "(cat temp) > output", "Enter", "Enter"], env=env)
-            time.sleep(5)
-            subprocess.Popen(["tmux", "send-keys", "-t", cont, "cat output", "Enter"], env=env)
-            time.sleep(10)
-            subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
-            time.sleep(2)
-
-            try:
-                output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env)
-                output = output.decode().split('Executed command: ')[1].strip()
-                print(output)
-            except Exception as e:
-                output = None
-                print(bad(f'Error capturing output from: {bold(cont)}'))
-
-
-        # Kill shell
-        subprocess.Popen(["tmux", "send-keys", "-t", cont, "(rm temp && rm output && exit)", "Enter"], env=env)
-        time.sleep(1)
-        # Kill tmux window
-        subprocess.Popen(["tmux", "kill-session", "-t", cont], env=env)
-
-        return cont, output
-
     def exec(self, command, max_retries=60, input_cmd: str = None):
-        global global_responses
+        global instances_outputs
         self.all_instances, self.instances_named = self.ls(interactive=False)
         results = []
         executed = False
@@ -335,7 +338,7 @@ class Acido(object):
             if cg in self.selected_instances:
                 for cont in containers:
                     executed = True
-                    result = pool.apply_async(self.exec_command, 
+                    result = pool.apply_async(exec_command, 
                                              (self.rg, cg, cont, command, max_retries), 
                                               callback=build_output)
                     results.append(result)
@@ -346,7 +349,7 @@ class Acido(object):
         
         results = [result.wait() for result in results]
 
-        for c, o in global_responses.items():
+        for c, o in instances_outputs.items():
             if o:
                 print(good(f'Executed command on {bold(c)}. Output: [\n{o}\n]'))
             else:
@@ -355,7 +358,7 @@ class Acido(object):
                 else:
                     print(bad(f'Executed command on {bold(c)} Output: FAILED TO PARSE'))
 
-        global_responses = {}
+        instances_outputs = {}
 
         return
 
@@ -418,6 +421,7 @@ if __name__ == "__main__":
     if args.select:
         acido.select(selection=args.select, interactive=bool(args.interactive))
     if args.exec_cmd:
+        print(args.exec_cmd)
         pool = ThreadPool(processes=30)
         acido.exec(command=args.exec_cmd)
     if args.remove:
